% fig_09_20
% plot Cartesian stress components near the uniform opening
% displacement discontinuity on a 2D line element
% Crouch and Starfield (1983)

clear all, clf reset; % clear memory and figures
% Element is centered at origin, parallel to x, and extends -a <= x <= +a
% Cartesian stress field and displacement field are calculated
dy = 0.001; % dy is displacement discontinuity perpendicular to element
mu = 30000; pr = 0.25; % Elastic shear modulus and Poisson's ratio
c = 1/(4*pi*(1-pr)); %constant multiplier for stress components
a = 1; % Line element half length
x=-2.5*a:.05*a+eps:2.5*a;   % Define x-coords. of grid
y=-2.5*a:.05*a:2.5*a;   % Define y-coords. of grid
[X,Y] = meshgrid(x,y); % define Cartesian grid
XMA2 = (X-a).^2; XPA2 = (X+a).^2; Y2 = Y.^2;
FCYY = -c*(((X-a)./(XMA2+Y2))-((X+a)./(XPA2+Y2)));
FCXYY = c*(((XMA2-Y2)./(XMA2+Y2).^2)-((XPA2-Y2)./(XPA2+Y2).^2));
FCYYY = (c*2.*Y).*(((X-a)./(XMA2+Y2).^2)-((X+a)./(XPA2+Y2).^2));
SXX = 2*mu*dy*(FCYY + Y.*FCYYY);
SYY = 2*mu*dy*(FCYY - Y.*FCYYY);
SXY = 2*mu*dy*(-Y.*FCXYY);
% Eliminate stress values near tips
R1 = sqrt((X-a).^2+Y.^2); R2 = sqrt((X+a).^2+Y.^2);
SXX(find(R1<(.09*a))) = nan; SXX(find(R2<(.09*a))) = nan;
SYY(find(R1<(.09*a))) = nan; SYY(find(R2<(.09*a))) = nan;
SXY(find(R1<(.09*a))) = nan; SXY(find(R2<(.09*a))) = nan;
SZZ = pr*(SXX+SYY); % out of plane normal stress
SM = (SXX+SYY+SZZ)/3; % mean normal stress
SS = sqrt(((SXX - SYY)./2).^2 + SXY.^2); % maximum shear stress
% plot contour maps, figure
contourf(X,Y,SXX,25)
title('stress sxx'), xlabel('x'), ylabel('y'), colorbar
figure, contourf(X,Y,SYY,15)
title('stress syy'), xlabel('x'), ylabel('y'), colorbar
figure, contourf(X,Y,SXY,15)
title('stress sxy'), xlabel('x'), ylabel('y'), colorbar
figure, contourf(X,Y,SZZ,15)
title('stress szz'), xlabel('x'), ylabel('y'), colorbar
figure, contourf(X,Y,SM,15)
title('mean normal stress'), xlabel('x'), ylabel('y'), colorbar
figure, contourf(X,Y,SS,15)
title('maximum shear stress'), xlabel('x'), ylabel('y'), colorbar

% Calculate principal stress trajectories and plot
G1 = 0.5*atan2(2*SXY, SXX-SYY);
U1 = cos(G1); V1 = sin(G1);
figure, QUIVER(X,Y,U1,V1,0.2,'.'), axis equal, hold on
G1 = G1+pi/2; U1 = cos(G1); V1 = sin(G1);
QUIVER(X,Y,U1,V1,0.4,'.')
G1 = G1+pi/2; U1 = cos(G1); V1 = sin(G1);
QUIVER(X,Y,U1,V1,0.2,'.')
G1 = G1+pi/2; U1 = cos(G1); V1 = sin(G1);
QUIVER(X,Y,U1,V1,0.4,'.')