% fig_09_31a
% plot Cartesian stress components near the mode-I crack tip
% Lawn and  Wilshaw (1975)
% equation (9.72)

clear all, clf reset; % clear memory and figures
k1 = 1; % mode-I stress intensity
pr = 0.25; % Poisson's ratio
ym = 25000; % Young's modulus, MPa
x=-0.031:0.001:0.031;   % Define x-coords. of grid
% x = x + eps; % add eps to avoid singularity at origin
y=-0.031:0.001:0.031;   % Define y-coords. of grid
[X,Y]=meshgrid(x,y);    % Define rectangular grid
[TH,R]=cart2pol(X,Y);   % Convert Cart. to polar coord.
ST2=sin(TH/2); S3T2=sin(3*TH/2); CT2=cos(TH/2); C3T2=cos(3*TH/2);
R2P=sqrt(2*pi*R);
R2P(find(R<0.0015)) = nan; % exclude calculations very near tip
SXX=k1*(CT2.*(1-ST2.*S3T2))./R2P;  % xx normal stress component
SYY=k1*(CT2.*(1+ST2.*S3T2))./R2P;  % yy normal stress component
SXY=k1*(ST2.*CT2.*C3T2)./R2P;      % xy shear stress component
SZZ=pr*(SXX+SYY); % zz normal stress component (plane strain)
% note out of-plane-shear stress SYZ = 0 = SZX
MSS=sqrt((0.5*(SXX-SYY)).^2 + SXY.^2); % maximum shear stress (photoelastic pattern)
MNS=(SXX+SYY+SZZ)/3; % mean normal stress
% strain energy density (SE), volumetric (VSE), distortional (DSE)
SE=((1/(2*ym))*(SXX.^2+SYY.^2+SZZ.^2))-((pr/ym)*(SXX.*SYY+SYY.*SZZ+SZZ.*SXX))+(((1+pr)/ym)*SXY.^2);
VSE=((1-2*pr)/(6*ym))*((SXX+SYY+SZZ).^2);
DSE=SE-VSE;
% contour plots of stress and energy components, figure, 
contourf(X,Y,SXX,10), colorbar, title('stress sxx')
xlabel('x-axis'), ylabel('y-axis')
figure, contourf(X,Y,SYY,10), colorbar, title('stress syy')
xlabel('x-axis'), ylabel('y-axis')
figure, contourf(X,Y,SXY,10), colorbar, title('stress sxy')
xlabel('x-axis'), ylabel('y-axis')
%figure, contourf(X,Y,SZZ,10), colorbar, title('stress szz')
%xlabel('x-axis'), ylabel('y-axis')
%figure, contourf(X,Y,MSS,10), colorbar, title('max. shear stress')
%xlabel('x-axis'), ylabel('y-axis')
%figure, contourf(X,Y,MNS,10), colorbar, title('mean normal stress')
%xlabel('x-axis'), ylabel('y-axis')
%figure, contourf(X,Y,SE,15), colorbar, title('strain energy density')
%xlabel('x-axis'), ylabel('y-axis')
%figure, contourf(X,Y,VSE,15), colorbar, title('volumetric strain energy density')
%xlabel('x-axis'), ylabel('y-axis')
%figure, contourf(X,Y,DSE,15), colorbar, title('distortional strain energy density')
%xlabel('x-axis'), ylabel('y-axis')

% figure, surf(X,Y,SXX)           % 3D plot of stress component
% xlabel('x-axis'), ylabel('y-axis'), zlabel('stress sxx')
% figure, surf(X,Y,SYY)
% xlabel('x-axis'), ylabel('y-axis'), zlabel('stress syy')
% figure, surf(X,Y,SXY)
% xlabel('x-axis'), ylabel('y-axis'), zlabel('stress sxy')